@@ -46,7 +46,7 @@ var (
 var clientCmd = &cobra.Command{
 	Use:   "client",
 	Short: "Client mode",
-	Run:   runClient,
+	Run:   runClientCmd,
 }
 
 func init() {
@@ -468,14 +468,17 @@ func (c *clientConfig) Config() (*client.Config, error) {
 	return hyConfig, nil
 }
 
-func runClient(cmd *cobra.Command, args []string) {
+func runClientCmd(cmd *cobra.Command, args []string) {
 	logger.Info("client mode")
+	runClient(defaultViper)
+}
 
-	if err := viper.ReadInConfig(); err != nil {
+func runClient(v *viper.Viper) {
+	if err := v.ReadInConfig(); err != nil {
 		logger.Fatal("failed to read client config", zap.Error(err))
 	}
 	var config clientConfig
-	if err := viper.Unmarshal(&config); err != nil {
+	if err := v.Unmarshal(&config); err != nil {
 		logger.Fatal("failed to parse client config", zap.Error(err))
 	}
 
