@@ -58,7 +58,7 @@ type clientImpl struct {
 	config *Config
 
 	pktConn net.PacketConn
-	conn    quic.Connection
+	conn    *quic.Conn
 
 	udpSM *udpSessionManager
 }
@@ -85,14 +85,15 @@ func (c *clientImpl) connect() (*HandshakeInfo, error) {
 		KeepAlivePeriod:                c.config.QUICConfig.KeepAlivePeriod,
 		DisablePathMTUDiscovery:        c.config.QUICConfig.DisablePathMTUDiscovery,
 		EnableDatagrams:                true,
+		MaxDatagramFrameSize:           protocol.MaxDatagramFrameSize,
 		DisablePathManager:             true,
 	}
 	// Prepare RoundTripper
-	var conn quic.EarlyConnection
-	rt := &http3.RoundTripper{
+	var conn *quic.Conn
+	rt := &http3.Transport{
 		TLSClientConfig: tlsConfig,
 		QUICConfig:      quicConfig,
-		Dial: func(ctx context.Context, _ string, tlsCfg *tls.Config, cfg *quic.Config) (quic.EarlyConnection, error) {
+		Dial: func(ctx context.Context, _ string, tlsCfg *tls.Config, cfg *quic.Config) (*quic.Conn, error) {
 			qc, err := quic.DialEarly(ctx, pktConn, c.config.ServerAddr, tlsCfg, cfg)
 			if err != nil {
 				return nil, err
@@ -163,7 +164,7 @@ func (c *clientImpl) connect() (*HandshakeInfo, error) {
 }
 
 // openStream wraps the stream with QStream, which handles Close() properly
-func (c *clientImpl) openStream() (quic.Stream, error) {
+func (c *clientImpl) openStream() (*utils.QStream, error) {
 	stream, err := c.conn.OpenStream()
 	if err != nil {
 		return nil, err
@@ -242,7 +243,7 @@ func wrapIfConnectionClosed(err error) error {
 }
 
 type tcpConn struct {
-	Orig             quic.Stream
+	Orig             *utils.QStream
 	PseudoLocalAddr  net.Addr
 	PseudoRemoteAddr net.Addr
 	Established      bool
@@ -292,7 +293,7 @@ func (c *tcpConn) SetWriteDeadline(t time.Time) error {
 }
 
 type udpIOImpl struct {
-	Conn quic.Connection
+	Conn *quic.Conn
 }
 
 func (io *udpIOImpl) ReceiveMessage() (*protocol.UDPMessage, error) {
